/**
 * Swap arguments of a binary function
 * @param fn Function to swap arguments
 * @returns Function that calls `fn`
 */
export const flip = fn => (x1, x0) => fn(x0, x1);
/**
 * Swap the first 2 arguments of an n-ary function
 * @param fn Function to swap arguments
 * @returns Function that calls `fn`
 */

export const flipXs = fn => (x1, x0, ...xs) => fn(x0, x1, ...xs);
/**
 * Turn a binary function into n-ary
 * by calling that function multiple times
 * @param fn Function to apply
 * @returns Function that calls `fn` multiple times
 */

export const nAry = fn => (...xs) => xs.reduce((x0, x1) => fn(x0, x1));
/**
 * Turn a binary function into n-ary
 * by calling that function multiple times
 * @param fn Function to apply
 * @returns Function that calls `fn` multiple times
 */

export const nAryRight = fn => (...xs) => xs.reduceRight((x0, x1) => fn(x0, x1)); //# sourceMappingURL=arity.js.map