/**
 * Call a nullary function
 * @param fn Function to call
 * @returns Result of function execution
 */
export declare const call0: <Y>(fn: () => Y) => Y;
/**
 * Call a unary function
 * @param fn Function to call
 * @param x Argument to pass to `fn`
 * @returns Result of function execution
 */
export declare const call1: <X, Y>(fn: (x: X) => Y, x: X) => Y;
/**
 * Call a binary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @returns Result of function execution
 */
export declare const call2: <X0, X1, Y>(fn: (x0: X0, x1: X1) => Y, x0: X0, x1: X1) => Y;
/**
 * Call a ternary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @param x2 Third argument to pass to `fn`
 * @returns Result of function execution
 */
export declare const call3: <X0, X1, X2, Y>(fn: (x0: X0, x1: X1, x2: X2) => Y, x0: X0, x1: X1, x2: X2) => Y;
/**
 * Call a n-ary function
 * @param fn Function to call
 * @param args Arguments to pass to `fn`
 * @returns Result of function execution
 */
export declare const callXs: <Xs extends any[], Y>(fn: (...args: Xs) => Y, ...args: Xs) => Y;
export { call0 as exec };
export { call1 as call };
