"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Call a nullary function
 * @param fn Function to call
 * @returns Result of function execution
 */
exports.call0 = (fn) => fn();
exports.exec = exports.call0;
/**
 * Call a unary function
 * @param fn Function to call
 * @param x Argument to pass to `fn`
 * @returns Result of function execution
 */
exports.call1 = (fn, x) => fn(x);
exports.call = exports.call1;
/**
 * Call a binary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @returns Result of function execution
 */
exports.call2 = (fn, x0, x1) => fn(x0, x1);
/**
 * Call a ternary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @param x2 Third argument to pass to `fn`
 * @returns Result of function execution
 */
exports.call3 = (fn, x0, x1, x2) => fn(x0, x1, x2);
/**
 * Call a n-ary function
 * @param fn Function to call
 * @param args Arguments to pass to `fn`
 * @returns Result of function execution
 */
exports.callXs = (fn, ...args) => fn(...args);
//# sourceMappingURL=call.js.map