/**
 * Call a nullary function
 * @param fn Function to call
 * @returns Result of function execution
 */
export const call0 = fn => fn();
/**
 * Call a unary function
 * @param fn Function to call
 * @param x Argument to pass to `fn`
 * @returns Result of function execution
 */

export const call1 = (fn, x) => fn(x);
/**
 * Call a binary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @returns Result of function execution
 */

export const call2 = (fn, x0, x1) => fn(x0, x1);
/**
 * Call a ternary function
 * @param fn Function to call
 * @param x0 First argument to pass to `fn`
 * @param x1 Second argument to pass to `fn`
 * @param x2 Third argument to pass to `fn`
 * @returns Result of function execution
 */

export const call3 = (fn, x0, x1, x2) => fn(x0, x1, x2);
/**
 * Call a n-ary function
 * @param fn Function to call
 * @param args Arguments to pass to `fn`
 * @returns Result of function execution
 */

export const callXs = (fn, ...args) => fn(...args);
export { call0 as exec };
export { call1 as call }; //# sourceMappingURL=call.js.map