"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Compose two unary functions
 * @param f Outer unary function
 * @param g Inner unary function
 * @returns Composite unary function
 */
exports.compose = (f, g) => (x) => f(g(x));
/**
 * Compose an n-ary function with an unary function
 * @param f Outer unary function
 * @param g Inner n-ary function
 * @returns Composite n-ary function
 */
exports.composeXs = (f, g) => (...xs) => f(g(...xs));
/**
 * Compose two unary functions
 * @param f Inner unary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */
exports.composeRight = (f, g) => exports.compose(g, f);
/**
 * Compose an unary function with an n-ary function
 * @param f Inner n-ary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */
exports.composeXsRight = (f, g) => exports.composeXs(g, f);
var ts_pipe_compose_1 = require("ts-pipe-compose");
exports.composeFns = ts_pipe_compose_1.composeUnary;
exports.composeFnsRight = ts_pipe_compose_1.pipelineUnary;
exports.composeFnsXs = ts_pipe_compose_1.compose;
exports.composeFnsXsRight = ts_pipe_compose_1.pipeline;
//# sourceMappingURL=compose.js.map