/**
 * Compose two unary functions
 * @param f Outer unary function
 * @param g Inner unary function
 * @returns Composite unary function
 */
export const compose = (f, g) => x => f(g(x));
/**
 * Compose an n-ary function with an unary function
 * @param f Outer unary function
 * @param g Inner n-ary function
 * @returns Composite n-ary function
 */

export const composeXs = (f, g) => (...xs) => f(g(...xs));
/**
 * Compose two unary functions
 * @param f Inner unary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */

export const composeRight = (f, g) => compose(g, f);
/**
 * Compose an unary function with an n-ary function
 * @param f Inner n-ary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */

export const composeXsRight = (f, g) => composeXs(g, f);
export { composeUnary as composeFns, pipelineUnary as composeFnsRight, compose as composeFnsXs, pipeline as composeFnsXsRight } from "ts-pipe-compose/index.mjs"; //# sourceMappingURL=compose.js.map