/**
 * Compose two unary functions
 * @param f Outer unary function
 * @param g Inner unary function
 * @returns Composite unary function
 */
export declare const compose: <X, Y, Z>(f: (y: Y) => Z, g: (x: X) => Y) => (x: X) => Z;
/**
 * Compose an n-ary function with an unary function
 * @param f Outer unary function
 * @param g Inner n-ary function
 * @returns Composite n-ary function
 */
export declare const composeXs: <Xs extends any[], Y, Z>(f: (y: Y) => Z, g: (...xs: Xs) => Y) => (...xs: Xs) => Z;
/**
 * Compose two unary functions
 * @param f Inner unary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */
export declare const composeRight: <X, Y, Z>(f: (x: X) => Y, g: (y: Y) => Z) => (x: X) => Z;
/**
 * Compose an unary function with an n-ary function
 * @param f Inner n-ary function
 * @param g Outer unary function
 * @returns Composite n-ary function
 */
export declare const composeXsRight: <Xs extends any[], Y, Z>(f: (...xs: Xs) => Y, g: (y: Y) => Z) => (...xs: Xs) => Z;
export { composeUnary as composeFns, pipelineUnary as composeFnsRight, compose as composeFnsXs, pipeline as composeFnsXsRight } from 'ts-pipe-compose';
